searchData={"content_type":"text/markdown","items":[{"doc":"Some helpers function to do validate data\n- Validate type\n- validate inclusion/exclusion\n- validate length for string and enumerable types\n- validate number\n- validate string format/pattern\n- validate custom function\n- validate required (not nil) or not\n- validate decimal\n\nEach of these validations can be used separatedly\n\n```elixir\niex> Valdi.validate_type(10, :integer)\n:ok\niex> Valdi.validate_type(10, :string)\n{:error, \"is not a string\"}\niex> Valdi.validate_number(9, [min: 10, max: 20])\n{:error, \"must be greater than or equal to 10\"}\n```\n\nOr you can combine multiple condition at one\n```elixir\niex> Valdi.validate(10, type: :integer, number: [min: 10, max: 20])\n:ok\niex> Valdi.validate(\"email@g.c\", type: :string, format: ~r/.+@.+.[a-z]{2,10}/)\n{:error, \"does not match format\"}\n```","ref":"Valdi.html","title":"Valdi","type":"module"},{"doc":"Validate value against list of validations.\n\n```elixir\niex> Valdi.validate(\"email@g.c\", type: :string, format: ~r/.+@.+.[a-z]{2,10}/)\n{:error, \"does not match format\"}\n```\n\n**All supported validations**:\n- `type`: validate datatype\n- `format`: check if binary value matched given regex\n- `number`: validate number value\n- `length`: validate length of supported types. See `validate_length/2` for more details.\n- `in`: validate inclusion\n- `not_in`: validate exclusion\n- `func`: custom validation function follows spec `func(any()):: :ok | {:error, message::String.t()}`\n- `each`: validate each item in list with given validator. Supports all above validator","ref":"Valdi.html#validate/2","title":"Valdi.validate/2","type":"function"},{"doc":"","ref":"Valdi.html#validate_decimal/2","title":"Valdi.validate_decimal/2","type":"function"},{"doc":"Apply validation for each array item","ref":"Valdi.html#validate_each_item/2","title":"Valdi.validate_each_item/2","type":"function"},{"doc":"Validate embed types","ref":"Valdi.html#validate_embed/2","title":"Valdi.validate_embed/2","type":"function"},{"doc":"Check if value is **not** included in the given enumerable. Similar to `validate_inclusion/2`","ref":"Valdi.html#validate_exclusion/2","title":"Valdi.validate_exclusion/2","type":"function"},{"doc":"Checks whether a string match the given regex.\n\n```elixir\niex> Valdi.validate_format(\"year: 2001\", ~r/year:\\s\\d{4}/)\n:ok\niex> Valdi.validate_format(\"hello\", ~r/+/)\n{:error, \"does not match format\"}\n```","ref":"Valdi.html#validate_format/2","title":"Valdi.validate_format/2","type":"function"},{"doc":"Check if value is included in the given enumerable.\n\n```elixir\niex> Valdi.validate_inclusion(1, [1, 2])\n:ok\niex> Valdi.validate_inclusion(1, {1, 2})\n{:error, \"given condition does not implement protocol Enumerable\"}\niex> Valdi.validate_inclusion(1, %{a: 1, b: 2})\n{:error, \"not be in the inclusion list\"}\niex> Valdi.validate_inclusion({:a, 1}, %{a: 1, b: 2})\n:ok\n```","ref":"Valdi.html#validate_inclusion/2","title":"Valdi.validate_inclusion/2","type":"function"},{"doc":"Check if length of value match given conditions. Length condions are the same with `validate_number/2`\n\n```elixir\niex> Valdi.validate_length([1], min: 2)\n{:error, \"length must be greater than or equal to 2\"}\niex> Valdi.validate_length(\"hello\", equal_to: 5)\n:ok\n```\n\n**Supported types**\n- `list`\n- `map`\n- `tuple`\n- `keyword`\n- `string`","ref":"Valdi.html#validate_length/2","title":"Valdi.validate_length/2","type":"function"},{"doc":"Validate list value aganst validator and return error if any item is not valid.\nIn case of error `{:error, errors}`, `errors` is list of error detail for all error item includes `[index, message]`\n\n```elixir\niex> Valdi.validate_list([1,2,3], type: :integer, number: [min: 2])\n{:error, [[0, \"must be greater than or equal to 2\"]]}\n```","ref":"Valdi.html#validate_list/2","title":"Valdi.validate_list/2","type":"function"},{"doc":"Validate map value with given map specification.\nValidation spec is a map\n\n`validate_map` use the key from validation to extract value from input data map and then validate value against the validators for that key.\n\nIn case of error, the error detail is a map of error for each key.\n\n```elixir\niex> validation_spec = %{\n...>  email: [type: :string, required: true],\n...>  password: [type: :string, length: [min: 8]],\n...>  age: [type: :integer, number: [min: 16, max: 60]]\n...>  }\niex> Valdi.validate_map(%{name: \"dzung\", password: \"123456\", email: \"ddd@example.com\", age: 28}, validation_spec)\n{:error, %{password: \"length must be greater than or equal to 8\"}}\n```","ref":"Valdi.html#validate_map/2","title":"Valdi.validate_map/2","type":"function"},{"doc":"Validate number value\n\n```elixir\niex> Valdi.validate_number(12, min: 10, max: 12)\n:ok\niex> Valdi.validate_number(12, min: 15)\n{:error, \"must be greater than or equal to 15\"}\n```\n\nSupport conditions\n- `equal_to`\n- `greater_than_or_equal_to` | `min`\n- `greater_than`\n- `less_than`\n- `less_than_or_equal_to` | `max`\n\n    validate_number(x, [min: 10, max: 20])","ref":"Valdi.html#validate_number/2","title":"Valdi.validate_number/2","type":"function"},{"doc":"Validate value if value is not nil. This function can receive a function to dynamicall calculate required or not.\n\n```elixir\niex> Valdi.validate_required(nil, true)\n{:error, \"is required\"}\niex> Valdi.validate_required(1, true)\n:ok\niex> Valdi.validate_required(nil, false)\n:ok\niex> Valdi.validate_required(nil, fn -> 2 == 2 end)\n{:error, \"is required\"}\n```","ref":"Valdi.html#validate_required/2","title":"Valdi.validate_required/2","type":"function"},{"doc":"Validate data types.\n\n```elixir\niex> Valdi.validate_type(\"a string\", :string)\n:ok\niex> Valdi.validate_type(\"a string\", :number)\n{:error, \"is not a number\"}\n```\n\nSupport built-in types:\n- `boolean`\n- `integer`\n- `float`\n- `number` (integer or float)\n- `string` | `binary`\n- `tuple`\n- `map`\n- `array`\n- `atom`\n- `function`\n- `keyword`\n- `date`\n- `datetime`\n- `naive_datetime`\n- `time`\n\nIt can also check extend types\n- `struct` Ex: `User`\n- `{:array, type}` : array of type","ref":"Valdi.html#validate_type/2","title":"Valdi.validate_type/2","type":"function"},{"doc":"","ref":"Valdi.html#t:error/0","title":"Valdi.error/0","type":"type"},{"doc":"","ref":"Valdi.html#t:support_length_types/0","title":"Valdi.support_length_types/0","type":"type"},{"doc":"# Valdi\n\n[![Build Status](https://github.com/bluzky/valdi/workflows/Elixir%20CI/badge.svg)](https://github.com/bluzky/valdi/actions) [![Coverage Status](https://coveralls.io/repos/github/bluzky/valdi/badge.svg?branch=main)](https://coveralls.io/github/bluzky/valdi?branch=main) [![Hex Version](https://img.shields.io/hexpm/v/valdi.svg)](https://hex.pm/packages/valdi) [![docs](https://img.shields.io/badge/docs-hexpm-blue.svg)](https://hexdocs.pm/valdi/)\n\n**Data validation for Elixir**","ref":"readme.html","title":"Valdi","type":"extras"},{"doc":"The package can be installed by adding `valdi` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:valdi, \"~> 0.5.0\"}\n  ]\nend\n```\n\nDocument can be found at [https://hexdocs.pm/valdi](https://hexdocs.pm/valdi).","ref":"readme.html#installation","title":"Installation - Valdi","type":"extras"},{"doc":"Some helpers function to do validate data\n- Validate type\n- validate inclusion/exclusion\n- validate length for string and enumerable types\n- validate number\n- validate string format/pattern\n- validate custom function\n- validate required(not nil) or not\n- validate decimal (thanks @madclaws)","ref":"readme.html#features","title":"Features - Valdi","type":"extras"},{"doc":"- Each of these validations can be used separatedly\n\n```elixir\niex(2)>   Valdi.validate_type(10, :integer)\n:ok\niex(3)>   Valdi.validate_type(10, :string)\n{:error, \"is not a string\"}\niex(3)>   Valdi.validate_number(9, [min: 10, max: 20])\n{:error, \"must be greater than or equal to 10\"}\n```\n\n- Or you can combine multiple condition at one\n\n```elixir\niex(12)> Valdi.validate(10, type: :integer, number: [min: 10, max: 20])\n:ok\niex(13)> Valdi.validate(\"email@g.c\", type: :string, format: ~r/.+@.+\\.[a-z]{2,10}/)\n{:error, \"format not matched\"}\n```\n\n- You can validate list of value\n\n```elixir\niex(51)> Valdi.validate_list([1,2,3], type: :integer, number: [min: 2])\n{:error, [[0, \"must be greater than or equal to 2\"]]}\n```\n\n- And validate map data too\n```elixir\niex(54)>  validation_spec = %{\n...(54)>     email: [type: :string],\n...(54)>     password: [type: :string, length: [min: 8]],\n...(54)>     age: [type: :integer, number: [min: 16, max: 60]]\n...(54)>   }\niex(56)> Valdi.validate_map(%{name: \"dzung\", password: \"123456\", emal: \"ddd@example.com\", age: 28}, validation_spec)\n{:error, %{password: \"length must be greater than or equal to 8\"}}\n```","ref":"readme.html#usage","title":"Usage - Valdi","type":"extras"},{"doc":"**Type validation for built-in types and collection:**\n\n- `:boolean`\n- `:integer`\n- `:float`\n- `:number`(int or float)\n- `:string`, `:binary`(string is binary alias)\n- `:tuple`\n- `:array`, `:list`\n- `:atom`\n- `:function`\n- `:map`\n- `:date`\n- `:time`\n- `:datetime`\n- `:naive_datetime`\n- `:utc_datetime`\n- `{:array, type}` array of item similar to Ecto.Schema \n- `:keyword`\n- `struct` for example: `User`. it's the struct module name\n\n```elixir\niex(11)> Valdi.validate([\"one\", \"two\", \"three\"],  type: {:array, :string})\n:ok\niex(12)> Valdi.validate([\"one\", \"two\", \"three\"],  type: :array)\n:ok\niex(13)> Valdi.validate([\"one\", \"two\", \"three\"],  type: :map)\n{:error, \"is not a map\"}\niex(14)>\n```\n\n**Validate required**\n Validate value if value is not nil. This function can receive a function to dynamicall calculate required or not.\n\n ```elixir\n  iex(1)> Magik.Validator.validate_required(nil, true)\n  {:error, \"is required\"}\n  iex(2)> Magik.Validator.validate_required(1, true)\n  :ok\n  iex(3)> Magik.Validator.validate_required(nil, false)\n  :ok\n  iex(4)> Magik.Validator.validate_required(nil, fn -> 2 == 2 end)\n  {:error, \"is required\"}\n  ```\n\n\n**Validate inclusion and exclusion**\n\n```elixir\niex(15)> Valdi.validate(\"one\", in: ~w(one two three))\n:ok\niex(16)> Valdi.validate(\"five\", in: ~w(one two three))\n{:error, \"not be in the inclusion list\"}\niex(17)> Valdi.validate(\"five\", not_in: ~w(one two three))\n:ok\n```\n\n**Validate format/regex**\n\n```elixir\niex(13)> Valdi.validate(\"email@g.c\", type: :string, format: ~r/.+@.+\\.[a-z]{2,10}/)\n{:error, \"format not matched\"}\niex(18)> Valdi.validate(\"123\", format: ~r/\\d{3}/)\n:ok\n```\n\n**Validate number**\n\nHere are list of check condition on number value:\n- `equal_to`\n- `greater_than_or_equal_to` | `min`\n- `greater_than`\n- `less_than`\n- `less_than_or_equal_to` | `max`\n\n```elixir\niex(19)> Valdi.validate(12, number: [greater_than: 0, less_than: 20])\n:ok\niex(20)> Valdi.validate(12, number: [min: 0, max: 10])\n{:error, \"must be less than or equal to 10\"}\niex(21)> Valdi.validate(12, number: [equal_to: 10])\n{:error, \"must be equal to 10\"}\niex(22)>\n```\n\n**Validate decimal**\nSimilar to validate number\n\n```elixir\niex(19)> Valdi.validate(Decimal.new(\"10.0\"), decimal: [greater_than: Decimal.new(\"0.0\"), less_than: Decimal.new(\"20.0\")])\n:ok\n```\n\n**Validate string and enumerable length**\n\nValdi supported check length for `map`, `list`, `binary`, `tuple`\nAll check conditions are the same with number validation\n\n```elixir\niex(24)> Valdi.validate(\"mypassword\", length: [min: 8, max: 16])\n:ok\niex(25)> Valdi.validate([1, 2, 3], length: [min: 3])\n:ok\niex(26)> Valdi.validate({\"one\", \"two\"}, length: [min: 3])\n{:error, \"length must be greater than or equal to 3\"}\niex(27)> Valdi.validate(50, length: [min: 2])\n{:error, \"length check supports only lists, binaries, maps and tuples\"}\n```\n\n**Custom validation function**\n\nYou can pass your validation function too. You function must follow spec:\n\n```elixir\nfunc(any()):: :ok | {:error, message::String.t()}\n```\n\n```elixir\niex(32)> Valdi.validate(12, func: fn val -> if is_binary(val), do: :ok, else: {:error, \"not a string\"} end)\n{:error, \"not a string\"}\n```\n\n**Validate each array element**\nSupport all above validator to validate each array element\n\n```elixir\niex(32)> Valdi.validate([1, 10, 20], each: [number: [min: 10]])\n\n{:error, [[0, \"must be greater than or equal to 10\"]]}\n```","ref":"readme.html#supported-validations","title":"Supported validations - Valdi","type":"extras"}]}